==> ah-formbuilder-1.2.3.tgz: package/es/utils/conditional-logic/index.js <==
var _jsxFileName = "/home/ayesha/Project/formbuilder/src/utils/conditional-logic/index.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useEffect, useState } from 'react';
import { connect } from "react-redux";
import _ from 'lodash';
import Checkbox from "../checkboxs/Checkbox";
import IconButton from "@material-ui/core/IconButton";
import AddIcon from '@material-ui/icons/Add';
import SearchableSelect from "../selects/SearchableSelect";
import './style.scss';
import ConditionItem from "./ConditionItem";
import Button from "@material-ui/core/Button";
var conditionalLabel = {
  en: 'Enable Conditional Logic',
  ar: 'تمكين المنطق الشرطي'
};

function ConditionalLogic(props) {
  var _props$conditionalLog,
      _props$conditionalLog2,
      _this = this;

  var _useState = useState((props == null ? void 0 : (_props$conditionalLog = props.conditionalLogic) == null ? void 0 : _props$conditionalLog.display) || ''),
      display = _useState[0],
      setDisplay = _useState[1];

  var _useState2 = useState((props == null ? void 0 : (_props$conditionalLog2 = props.conditionalLogic) == null ? void 0 : _props$conditionalLog2.logic) || ''),
      logic = _useState2[0],
      setLogic = _useState2[1];

  useEffect(function () {
    var _props$conditionalLog3, _props$conditionalLog4;

    setDisplay((props == null ? void 0 : (_props$conditionalLog3 = props.conditionalLogic) == null ? void 0 : _props$conditionalLog3.display) || '');
    setLogic((props == null ? void 0 : (_props$conditionalLog4 = props.conditionalLogic) == null ? void 0 : _props$conditionalLog4.logic) || '');
  }, [props == null ? void 0 : props.conditionalLogic]);

  var conditionalLogic = _.cloneDeep(props == null ? void 0 : props.conditionalLogic);

  var singleFields = [];
  var multiFields = [];
  var textFields = [];
  var numberFields = [];
  var fields = [];

  var extractOptionsFromPredefined = function extractOptionsFromPredefined(referenceId, options) {
    if (referenceId) {
      for (var i = 0; i < props.predefined.length; i++) {
        if (props.predefined[i].id === referenceId) {
          return props.predefined[i].options;
        }
      }
    }

    return options;
  };

  var getOptions = function getOptions() {
    var options = {};

    var allFields = _extends({}, props.conditionableFields, {}, props.data);

    _.map(allFields, function (field, uuid) {
      if (field.type === 'select') {
        if (field.config.isMultiple) {
          multiFields.push(field.machineName);
        } else {
          singleFields.push(field.machineName);
        }

        fields.push(field);

        if (['hiring_manager'].includes(field.machineName)) {
          var _props$users;

          options[field.machineName] = (_props$users = props.users) == null ? void 0 : _props$users.map(function (user) {
            return {
              name: user.name,
              id: user.id
            };
          });
        } else options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'radio') {
        singleFields.push(field.machineName);
        fields.push(field);
        options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'checkbox') {
        multiFields.push(field.machineName);
        fields.push(field);
        options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'text') {
        if (field.config.subType === 'number') {
          numberFields.push(field.machineName);
          fields.push(field);
        } else {
          textFields.push(field.machineName);
          fields.push(field);
        }
      }
    });

    return options;
  };

  var handleChange = function handleChange(val, name) {
    var _extends2;

    props.handleChange(_extends({}, props.conditionalLogic, (_extends2 = {}, _extends2[name] = val, _extends2)), 'conditionalLogic');
  };

  var enableConditionalLogic = function enableConditionalLogic(val) {
    props.handleChange(val, 'isConditionalEnabled');

    if (!val) {
      props.handleChange(_extends({}, props.conditionalLogic, {
        conditions: []
      }), 'conditionalLogic');
    }
  };

  var handleConditionChange = function handleConditionChange(val, index) {
    var _props$conditionalLog5;

    var conditions = _.cloneDeep(props == null ? void 0 : (_props$conditionalLog5 = props.conditionalLogic) == null ? void 0 : _props$conditionalLog5.conditions);

    conditions[index] = val;
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var addCondition = function addCondition() {
    var _props$conditionalLog6;

    var conditions = _.cloneDeep(props == null ? void 0 : (_props$conditionalLog6 = props.conditionalLogic) == null ? void 0 : _props$conditionalLog6.conditions);

    conditions.push({
      field: null,
      operator: '',
      value: ''
    });
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var _deleteCondition = function deleteCondition(index) {
    var _props$conditionalLog7;

    var conditions = props == null ? void 0 : (_props$conditionalLog7 = props.conditionalLogic) == null ? void 0 : _props$conditionalLog7.conditions;
    conditions.splice(index, 1);
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var renderConditions = function renderConditions() {
    var options = getOptions();

    if (conditionalLogic == null ? void 0 : conditionalLogic.conditions.length) {
      return conditionalLogic == null ? void 0 : conditionalLogic.conditions.map(function (condition, index) {
        var errors = props.errors[index] ? props.errors[index] : {};
        return /*#__PURE__*/React.createElement(ConditionItem, {
          key: index,
          errors: errors,
          index: index,
          handleChange: function handleChange(val) {
            return handleConditionChange(val, index);
          },
          deleteCondition: function deleteCondition(e) {
            return _deleteCondition(index);
          },
          fields: fields,
          condition: condition,
          multiFields: multiFields,
          singleFields: singleFields,
          textFields: textFields,
          numberFields: numberFields,
          options: options,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 135,
            columnNumber: 11
          }
        });
      });
    } else {
      return /*#__PURE__*/React.createElement("div", {
        className: "ahfb-width-full ahfb-py-3 ahfb-text-center",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 140,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("p", {
        className: "ahfb-text-muted",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 141,
          columnNumber: 11
        }
      }, "Click below to add condition."));
    }
  };

  if (props == null ? void 0 : props.isConditionalEnabled) {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 149,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 150,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement(Checkbox, {
      checked: props.isConditionalEnabled,
      handleChange: function handleChange(val) {
        return enableConditionalLogic(val);
      },
      label: "Enable Conditional Logic",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 151,
        columnNumber: 11
      }
    })), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-d-flow-root",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 153,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("span", {
      className: "ahfb-float-left ahfb-conditional-main-dropdowns ahfb-mr-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 154,
        columnNumber: 11
      }
    }, /*#__PURE__*/React.createElement(SearchableSelect, {
      value: display,
      handleChange: function handleChange(e) {
        return setDisplay(e.target.value);
      },
      options: [{
        label: 'Show',
        value: 'show'
      }, {
        label: 'Hide',
        value: 'hide'
      }],
      disableClearable: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 155,
        columnNumber: 13
      }
    })), /*#__PURE__*/React.createElement("span", {
      className: "ahfb-d-flex ahfb-float-left ahfb-mt-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 157,
        columnNumber: 11
      }
    }, " this field if "), /*#__PURE__*/React.createElement("span", {
      className: "ahfb-float-left ahfb-conditional-main-dropdowns ahfb-mx-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 158,
        columnNumber: 11
      }
    }, /*#__PURE__*/React.createElement(SearchableSelect, {
      value: logic,
      handleChange: function handleChange(e) {
        return setLogic(e.target.value);
      },
      options: [{
        label: 'All',
        value: 'all'
      }, {
        label: 'Any',
        value: 'any'
      }],
      disableClearable: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 159,
        columnNumber: 13
      }
    })), /*#__PURE__*/React.createElement("span", {
      className: "ahfb-d-flex ahfb-float-left ahfb-mt-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 161,
        columnNumber: 11
      }
    }, " of the following match:")), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-mt-2",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 163,
        columnNumber: 9
      }
    }, renderConditions(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-clearfix",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 165,
        columnNumber: 11
      }
    }, /*#__PURE__*/React.createElement(Button, {
      onClick: addCondition,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 166,
        columnNumber: 13
      }
    }, /*#__PURE__*/React.createElement(AddIcon, {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 166,
        columnNumber: 45
      }
    }), " ", (conditionalLogic == null ? void 0 : conditionalLogic.conditions.length) ? 'Add another condition' : 'Add condition'))));
  } else {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 173,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(Checkbox, {
      checked: props.isConditionalEnabled,
      handleChange: function handleChange(val) {
        return enableConditionalLogic(val);
      },
      label: conditionalLabel[props.currentLang],
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 174,
        columnNumber: 9
      }
    }));
  }
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    data: state.form.data,
    users: state.form.users,
    conditionableFields: state.form.conditionableFields,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {};
};

export default connect(mapStateToProps, mapDispatchToProps)(ConditionalLogic);

==> ah-formbuilder-1.2.4.tgz: package/es/utils/conditional-logic/index.js <==
var _jsxFileName = "/home/ayesha/Project/formbuilder/src/utils/conditional-logic/index.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useEffect } from 'react';
import { connect } from "react-redux";
import _ from 'lodash';
import Checkbox from "../checkboxs/Checkbox";
import IconButton from "@material-ui/core/IconButton";
import AddIcon from '@material-ui/icons/Add';
import SearchableSelect from "../selects/SearchableSelect";
import './style.scss';
import ConditionItem from "./ConditionItem";
import Button from "@material-ui/core/Button";
var conditionalLabel = {
  en: 'Enable Conditional Logic',
  ar: 'تمكين المنطق الشرطي'
};

function ConditionalLogic(props) {
  var _this = this;

  var conditionalLogic = _.cloneDeep(props == null ? void 0 : props.conditionalLogic);

  var singleFields = [];
  var multiFields = [];
  var textFields = [];
  var numberFields = [];
  var fields = [];

  var extractOptionsFromPredefined = function extractOptionsFromPredefined(referenceId, options) {
    if (referenceId) {
      for (var i = 0; i < props.predefined.length; i++) {
        if (props.predefined[i].id === referenceId) {
          return props.predefined[i].options;
        }
      }
    }

    return options;
  };

  var getOptions = function getOptions() {
    var options = {};

    var allFields = _extends({}, props.conditionableFields, {}, props.data);

    _.map(allFields, function (field, uuid) {
      if (field.type === 'select') {
        if (field.config.isMultiple) {
          multiFields.push(field.machineName);
        } else {
          singleFields.push(field.machineName);
        }

        fields.push(field);

        if (['hiring_manager'].includes(field.machineName)) {
          var _props$users;

          options[field.machineName] = (_props$users = props.users) == null ? void 0 : _props$users.map(function (user) {
            return {
              name: user.name,
              id: user.id
            };
          });
        } else options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'radio') {
        singleFields.push(field.machineName);
        fields.push(field);
        options[field.machineName] = options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'checkbox') {
        multiFields.push(field.machineName);
        fields.push(field);
        options[field.machineName] = options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'text') {
        if (field.config.subType === 'number') {
          numberFields.push(field.machineName);
          fields.push(field);
        } else {
          textFields.push(field.machineName);
          fields.push(field);
        }
      }
    });

    return options;
  };

  var _handleChange = function handleChange(val, name) {
    var _extends2;

    props.handleChange(_extends({}, props.conditionalLogic, (_extends2 = {}, _extends2[name] = val, _extends2)), 'conditionalLogic');
  };

  var enableConditionalLogic = function enableConditionalLogic(val) {
    props.handleChange(val, 'isConditionalEnabled');

    if (!val) {
      props.handleChange(_extends({}, props.conditionalLogic, {
        conditions: []
      }), 'conditionalLogic');
    }
  };

  var handleConditionChange = function handleConditionChange(val, index) {
    var _props$conditionalLog;

    var conditions = _.cloneDeep(props == null ? void 0 : (_props$conditionalLog = props.conditionalLogic) == null ? void 0 : _props$conditionalLog.conditions);

    conditions[index] = val;
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var addCondition = function addCondition() {
    var _props$conditionalLog2;

    var conditions = _.cloneDeep(props == null ? void 0 : (_props$conditionalLog2 = props.conditionalLogic) == null ? void 0 : _props$conditionalLog2.conditions);

    conditions.push({
      field: null,
      operator: '',
      value: ''
    });
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var _deleteCondition = function deleteCondition(index) {
    var _props$conditionalLog3;

    var conditions = props == null ? void 0 : (_props$conditionalLog3 = props.conditionalLogic) == null ? void 0 : _props$conditionalLog3.conditions;
    conditions.splice(index, 1);
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var renderConditions = function renderConditions() {
    var options = getOptions();

    if (conditionalLogic == null ? void 0 : conditionalLogic.conditions.length) {
      return conditionalLogic == null ? void 0 : conditionalLogic.conditions.map(function (condition, index) {
        var errors = props.errors[index] ? props.errors[index] : {};
        return /*#__PURE__*/React.createElement(ConditionItem, {
          key: index,
          errors: errors,
          index: index,
          handleChange: function handleChange(val) {
            return handleConditionChange(val, index);
          },
          deleteCondition: function deleteCondition(e) {
            return _deleteCondition(index);
          },
          fields: fields,
          condition: condition,
          multiFields: multiFields,
          singleFields: singleFields,
          textFields: textFields,
          numberFields: numberFields,
          options: options,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 129,
            columnNumber: 11
          }
        });
      });
    } else {
      return /*#__PURE__*/React.createElement("div", {
        className: "ahfb-width-full ahfb-py-3 ahfb-text-center",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 134,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("p", {
        className: "ahfb-text-muted",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 135,
          columnNumber: 11
        }
      }, "Click below to add condition."));
    }
  };

  if (props == null ? void 0 : props.isConditionalEnabled) {
    var _props$conditionalLog4, _props$conditionalLog5;

    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 143,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 144,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement(Checkbox, {
      checked: props.isConditionalEnabled,
      handleChange: function handleChange(val) {
        return enableConditionalLogic(val);
      },
      label: "Enable Conditional Logic",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 145,
        columnNumber: 11
      }
    })), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-d-flow-root",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 147,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("span", {
      className: "ahfb-float-left ahfb-conditional-main-dropdowns ahfb-mr-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 148,
        columnNumber: 11
      }
    }, /*#__PURE__*/React.createElement(SearchableSelect, {
      value: props == null ? void 0 : (_props$conditionalLog4 = props.conditionalLogic) == null ? void 0 : _props$conditionalLog4.display,
      handleChange: function handleChange(e) {
        return _handleChange(e.target.value, 'display');
      },
      options: [{
        label: 'Show',
        value: 'show'
      }, {
        label: 'Hide',
        value: 'hide'
      }],
      disableClearable: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 148,
        columnNumber: 87
      }
    })), /*#__PURE__*/React.createElement("span", {
      className: "ahfb-d-flex ahfb-float-left ahfb-mt-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 149,
        columnNumber: 11
      }
    }, " this field if "), /*#__PURE__*/React.createElement("span", {
      className: "ahfb-float-left ahfb-conditional-main-dropdowns ahfb-mx-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 150,
        columnNumber: 11
      }
    }, /*#__PURE__*/React.createElement(SearchableSelect, {
      value: props == null ? void 0 : (_props$conditionalLog5 = props.conditionalLogic) == null ? void 0 : _props$conditionalLog5.logic,
      handleChange: function handleChange(e) {
        return _handleChange(e.target.value, 'logic');
      },
      options: [{
        label: 'All',
        value: 'all'
      }, {
        label: 'Any',
        value: 'any'
      }],
      disableClearable: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 150,
        columnNumber: 87
      }
    })), /*#__PURE__*/React.createElement("span", {
      className: "ahfb-d-flex ahfb-float-left ahfb-mt-1",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 151,
        columnNumber: 11
      }
    }, " of the following match:")), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-mt-2",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 153,
        columnNumber: 9
      }
    }, renderConditions(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-clearfix",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 155,
        columnNumber: 11
      }
    }, /*#__PURE__*/React.createElement(Button, {
      onClick: addCondition,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 156,
        columnNumber: 13
      }
    }, /*#__PURE__*/React.createElement(AddIcon, {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 156,
        columnNumber: 45
      }
    }), " ", (conditionalLogic == null ? void 0 : conditionalLogic.conditions.length) ? 'Add another condition' : 'Add condition'))));
  } else {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 163,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(Checkbox, {
      checked: props.isConditionalEnabled,
      handleChange: function handleChange(val) {
        return enableConditionalLogic(val);
      },
      label: conditionalLabel[props.currentLang],
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 164,
        columnNumber: 9
      }
    }));
  }
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    data: state.form.data,
    users: state.form.users,
    conditionableFields: state.form.conditionableFields,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {};
};

export default connect(mapStateToProps, mapDispatchToProps)(ConditionalLogic);
